@@ -31,7 +31,7 @@ class Attributes:
         if len(self.__attr) == 0:
             return ""
         else:
-            return begin + sep.join(sorted(k + "=\"" + self.__attr[k] + "\"" for k in self.__attr)) + end
+            return begin + sep.join(sorted(k + "=\"" + self.__attr[k].replace('"', '\\"') + "\"" for k in self.__attr)) + end
 
 
 class Attributed:
@@ -116,7 +116,7 @@ class BasicGraph(Attributed):
             + "}"
         )
 
-    def drawTo(self, fileName):
+    def drawTo(self, fileName):  # pragma no cover (Really calls 'dot')
         p = subprocess.Popen(["dot", "-Tpng", "-o" + fileName], stdin=subprocess.PIPE)
         p.communicate(self.dotString().encode())
 
@@ -153,8 +153,7 @@ def makeId(s):
     def replace(c):
         return "_" + format(ord(c), "02x")
 
-    if s == "":
-        return "_"
+    s = str(s)
 
     if shouldReplace(s[0]) or s[0] in "0123456789":
         s2 = replace(s[0])
